@@ -26,6 +26,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 域名配置更新操作失败，请重试或联系客服人员解决。
 FAILEDOPERATION_CDNCONFIGERROR = 'FailedOperation.CdnConfigError'
 
+# 数据查询错误，请联系腾讯云工程师进一步排查。
+FAILEDOPERATION_DATASYSTEMERROR = 'FailedOperation.DataSystemError'
+
 # 证书不存在
 FAILEDOPERATION_SSLCERTNOTFOUND = 'FailedOperation.SslCertNotFound'
 
@@ -443,7 +446,7 @@ UNAUTHORIZEDOPERATION_CDNCAMUNAUTHORIZED = 'UnauthorizedOperation.CdnCamUnauthor
 # 该账号未授权开通CLS。
 UNAUTHORIZEDOPERATION_CDNCLSNOTREGISTERED = 'UnauthorizedOperation.CdnClsNotRegistered'
 
-# 域名解析未进行验证。
+# 域名未进行归属权校验。
 UNAUTHORIZEDOPERATION_CDNDOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.CdnDomainRecordNotVerified'
 
 # 域名在内部系统已存在，请提工单处理。
